"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.toBeChecked = void 0;
const utils_1 = require("../utils/utils");
/**
 * Use `toBeChecked` function when you want to check that an element is enabled
 *
 * @example
 * ```typescript
 * // could be used with Promise<ElementHandle>
 * await expect(page.$('.btn')).toBeChecked();
 *
 * // or with ElementHandle
 * const toastElement = await page.$('.btn);
 * await expect(toastElement).toBeChecked();
 *
 * // or using an array of page and selector
 * await expect([page, '.btn']).toBeChecked(true);
 *
 * ```
 *
 * @param this
 * @param element
 * @param expectedState
 * @param options
 * @returns
 */
async function toBeChecked(element, expectedState = true, options) {
    try {
        const elementHandle = await utils_1.getElementHandle(element, options === null || options === void 0 ? void 0 : options.waitForState);
        const actualState = await elementHandle.isChecked();
        return {
            pass: actualState === expectedState,
            message: () => utils_1.getErrorMessage(this, 'toBeChecked', expectedState.toString(), actualState.toString()),
        };
    }
    catch (error) {
        return {
            pass: false,
            // eslint-disable-next-line @typescript-eslint/ban-ts-comment
            // @ts-ignore
            message: () => error.toString(),
        };
    }
}
exports.toBeChecked = toBeChecked;
