"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.toBeVisible = void 0;
const utils_1 = require("../utils/utils");
/**
 * Use `toBeVisible` function when you want to check that an element is visible
 *
 * @example
 * ```typescript
 * // could be used with Promise<ElementHandle>
 * await expect(page.$('.btn')).toBeVisible(true);
 *
 * // or with ElementHandle
 * const toastElement = await page.$('.btn);
 * await expect(toastElement).toBeVisible(true);
 *
 * // or using an array of page and selector
 * await expect([page, '.btn']).toBeVisible(true);
 *
 * ```
 *
 * @param this
 * @param element
 * @param expectedState
 * @param options
 * @returns
 */
async function toBeVisible(element, expectedState = true, options) {
    try {
        const elementHandle = await utils_1.getElementHandle(element, options === null || options === void 0 ? void 0 : options.waitForState);
        let actualState = false;
        if (elementHandle) {
            actualState = await elementHandle.isVisible();
        }
        return {
            pass: actualState === expectedState,
            message: () => utils_1.getErrorMessage(this, 'toBeVisible', expectedState.toString(), actualState.toString()),
        };
    }
    catch (error) {
        return {
            pass: false,
            // eslint-disable-next-line @typescript-eslint/ban-ts-comment
            // @ts-ignore
            message: () => error.toString(),
        };
    }
}
exports.toBeVisible = toBeVisible;
