"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.toHaveUrl = void 0;
const utils_1 = require("../utils/utils");
/**
 * Use `toHaveUrl` function when you want to check that page's url is equal to the expected url
 *
 * @example
 * ```typescript
 * await expect(page).toHaveUrl('https://example.com/');
 *
 * // also you can wait for the url
 * await expect(page).toHaveUrl('https://example.com/', {timeout: 5000})
 * ```
 *
 * @param this
 * @param page
 * @param expectedUrl
 * @param options
 * @returns
 */
async function toHaveUrl(page, expectedUrl, options) {
    try {
        if (options === null || options === void 0 ? void 0 : options.timeout) {
            await page.waitForURL(expectedUrl, { timeout: options.timeout });
        }
        const actualUrl = page.url();
        return {
            pass: actualUrl === expectedUrl,
            message: () => utils_1.getErrorMessage(this, 'toHaveUrl', expectedUrl, actualUrl),
        };
    }
    catch (error) {
        return {
            pass: false,
            // eslint-disable-next-line @typescript-eslint/ban-ts-comment
            // @ts-ignore
            message: () => error.toString(),
        };
    }
}
exports.toHaveUrl = toHaveUrl;
