"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getErrorMessage = exports.formatText = exports.getText = exports.getValue = exports.getElements = exports.getElementHandle = void 0;
const constants_1 = require("./constants");
// eslint-disable-next-line consistent-return
async function getElementHandle(element, waitOptions) {
    var _a, _b;
    // Handle PageSelector case. For instance: expect([page, selector])...
    if (Array.isArray(element)) {
        const [page, selector] = element;
        if (waitOptions) {
            const elementHandle = await page.waitForSelector(selector, {
                state: (_a = waitOptions.state) !== null && _a !== void 0 ? _a : 'visible',
                timeout: (_b = waitOptions.timeout) !== null && _b !== void 0 ? _b : constants_1.DEFAULT_TIMEOUT,
            });
            if (elementHandle)
                return elementHandle;
        }
        const elementHandle = await page.$(selector);
        if (elementHandle)
            return elementHandle;
        // Do nothing, just return element if it's ElementHandle. For instance: expect(await page.$('.btn'))...
    }
    else if ((element === null || element === void 0 ? void 0 : element.constructor.name) === 'ElementHandle') {
        if (waitOptions === null || waitOptions === void 0 ? void 0 : waitOptions.selector) {
            await (await element).waitForSelector(waitOptions.selector, {
                state: waitOptions.state || 'visible',
                timeout: waitOptions.timeout || constants_1.DEFAULT_TIMEOUT,
            });
        }
        return element;
        // Do nothing too, just return element if it's Promise<ElementHandle>. For instance: expect(page.$('.btn'))...
    }
    else if (element instanceof Promise) {
        if (waitOptions === null || waitOptions === void 0 ? void 0 : waitOptions.selector) {
            await (await element).waitForSelector(waitOptions.selector, {
                state: waitOptions.state || 'visible',
                timeout: waitOptions.timeout || constants_1.DEFAULT_TIMEOUT,
            });
        }
        return element;
    }
    return null;
}
exports.getElementHandle = getElementHandle;
async function getElements(elements) {
    let elementHandles;
    if (Array.isArray(elements) && elements[0].constructor.name === 'Page' && typeof elements[1] === 'string') {
        const [page, selector] = elements;
        // eslint-disable-next-line @typescript-eslint/ban-ts-comment
        // @ts-ignore
        elementHandles = await page.$$(selector);
    }
    else if (elements instanceof Promise) {
        elementHandles = await elements;
        return elementHandles;
    }
    else {
        elementHandles = elements;
    }
    // eslint-disable-next-line @typescript-eslint/ban-ts-comment
    // @ts-ignore
    return elementHandles;
}
exports.getElements = getElements;
async function getValue(elementHandle) {
    const element = await elementHandle;
    const value = await element.evaluate((input) => input.value);
    return value;
}
exports.getValue = getValue;
async function getText(elementHandle, textMethod = constants_1.DEFAULT_OPTIONS.textMethod) {
    var _a;
    const element = await elementHandle;
    if (element)
        return (_a = (await element[textMethod !== null && textMethod !== void 0 ? textMethod : 'textContent']())) !== null && _a !== void 0 ? _a : '';
    return '';
}
exports.getText = getText;
function formatText(text, { ignoreCase = false, trim = false }) {
    if (trim) {
        return text.trim();
    }
    if (ignoreCase) {
        return text.toLowerCase();
    }
    return text;
}
exports.formatText = formatText;
const getErrorMessage = ({ expand, isNot, promise, utils }, matcher, expected, received) => {
    const message = isNot
        ? `Expected: not ${utils.printExpected(expected)}`
        : `${utils.printDiffOrStringify(expected, received, 'Expected', 'Received', expand)}`;
    return `${utils.matcherHint(matcher, undefined, undefined, { isNot, promise })}\n\n${message}`;
};
exports.getErrorMessage = getErrorMessage;
